# MemoRizz Contributor License Agreement (CLA)

Thank you for your interest in contributing to MemoRizz (the "Project"), owned and maintained by Richmond Alake (the "Maintainer"). This Contributor License Agreement ("Agreement") documents the rights granted by contributors to the Maintainer.

## 1. Definitions

**"Contribution"** means any original work of authorship, including any modifications or additions to an existing work, that is intentionally submitted to the Project. "Submitted" means any form of communication sent to the Project, including but not limited to pull requests, issues, commits, patches, and emails.

**"You" (or "Your")** means the individual or legal entity making the Contribution.

## 2. Grant of Copyright License

By submitting a Contribution, You hereby grant to the Maintainer a perpetual, worldwide, non-exclusive, no-charge, royalty-free, irrevocable copyright license to reproduce, prepare derivative works of, publicly display, publicly perform, sublicense, and distribute Your Contributions and such derivative works.

## 3. Grant of Patent License

By submitting a Contribution, You hereby grant to the Maintainer a perpetual, worldwide, non-exclusive, no-charge, royalty-free, irrevocable patent license to make, have made, use, offer to sell, sell, import, and otherwise transfer the Contribution, where such license applies only to those patent claims licensable by You that are necessarily infringed by Your Contribution alone or by combination of Your Contribution with the Project.

## 4. Representations

You represent that:

(a) You are legally entitled to grant the above licenses. If Your employer has rights to intellectual property that You create, You represent that You have received permission to make Contributions on behalf of that employer, or that Your employer has waived such rights for Your Contributions to this Project.

(b) Each of Your Contributions is Your original creation. You represent that Your Contribution submissions include complete details of any third-party license or other restriction (including, but not limited to, related patents and trademarks) of which You are personally aware and which are associated with any part of Your Contributions.

(c) Your Contribution does not include any third-party code or content unless You have clearly identified and disclosed such third-party materials and their applicable licenses.

## 5. No Obligation

You understand that the decision to include Your Contribution in the Project is entirely at the discretion of the Maintainer and that this Agreement does not obligate the Maintainer to use or include Your Contribution.

## 6. Ownership

Except for the licenses granted herein, You reserve all right, title, and interest in and to Your Contributions.

## 7. Support and Warranty Disclaimer

Your Contributions are provided on an "AS IS" basis, without warranties or conditions of any kind, either express or implied, including any implied warranties of merchantability or fitness for a particular purpose. You are not expected to provide support for Your Contributions.

## 8. Agreement

By submitting a Contribution (pull request, patch, or other code submission) to this Project, You indicate Your acceptance of this Agreement.

---

**Project**: MemoRizz
**Project Owner**: Richmond Alake
**License**: PolyForm Noncommercial 1.0.0
**Effective Date**: 2024

For questions about this CLA, contact: richmond.alake@gmail.com
